@@ -10,12 +10,13 @@ class V1ChildNameChecker(AbstractChecker):
         logs = []
         properties = node.properties_list or []
         child_start_with_parent_name = [
-            prop.lower().startswith(node.name.lower())
-            for prop in properties
+            prop.lower().startswith(node.name.lower()) for prop in properties
         ]
         if any(child_start_with_parent_name):
-            logs += [(
-                f"Child property prefix uses the same name as the parent property '{node.name}'",
-                Log.WARNING.value
-            )]
+            logs += [
+                (
+                    f"Child property prefix uses the same name as the parent property '{node.name}'",
+                    Log.WARNING.value,
+                )
+            ]
         return logs
