@@ -11,40 +11,17 @@ TIME_LOOKUP = f"{LABELS}.items.properties.time.properties.lookup"
 path_to_checks = {
     ITEMS: {
         "type": "object",
-        "required": [
-            "source",
-            "name",
-            "value",
-            "time"
-        ],
+        "required": ["source", "name", "value", "time"],
     },
     SOURCE: {
         "type": "object",
-        "required": [
-            "name",
-            "type"
-        ],
-        "min_properties": ["name", "type"]
+        "required": ["name", "type"],
+        "min_properties": ["name", "type"],
     },
-    SOURCE_NAME: {
-        "type": "string"
-    },
-    SOURCE_TYPE: {
-        "type":  ["string", "null"]
-
-    },
-    NAME: {
-        "type": "string"
-    },
-    VALUE: {
-        "type": "string"
-    },
-    TIME: {
-        "type": "object",
-        "required": ["lookup"],
-        "min_properties": ["lookup"]
-    },
-    TIME_LOOKUP: {
-        "type": ["string", "null"]
-    }
-}
\ No newline at end of file
+    SOURCE_NAME: {"type": "string"},
+    SOURCE_TYPE: {"type": ["string", "null"]},
+    NAME: {"type": "string"},
+    VALUE: {"type": "string"},
+    TIME: {"type": "object", "required": ["lookup"], "min_properties": ["lookup"]},
+    TIME_LOOKUP: {"type": ["string", "null"]},
+}
